@@ -1,9 +1,11 @@
 var interfacecom_1_1sun_1_1star_1_1ui_1_1test_1_1XUITest =
 [
     [ "executeCommand", "interfacecom_1_1sun_1_1star_1_1ui_1_1test_1_1XUITest.html#ade05c8bf5f096b75a5456b63717e5859", null ],
+    [ "executeCommandForProvider", "interfacecom_1_1sun_1_1star_1_1ui_1_1test_1_1XUITest.html#a0451f0c497defa9737bb105f1f4bb44e", null ],
     [ "executeCommandWithParameters", "interfacecom_1_1sun_1_1star_1_1ui_1_1test_1_1XUITest.html#aacc028a43c51fa5f856b0e2e22e1cd8b", null ],
     [ "executeDialog", "interfacecom_1_1sun_1_1star_1_1ui_1_1test_1_1XUITest.html#ab8f399218fad801934b282e5ae8a1389", null ],
     [ "getFloatWindow", "interfacecom_1_1sun_1_1star_1_1ui_1_1test_1_1XUITest.html#aab165bef19ce65ba7e60d45c7e90a14f", null ],
+    [ "getFocusWindow", "interfacecom_1_1sun_1_1star_1_1ui_1_1test_1_1XUITest.html#a56da69650be14680e499db8210aa05bc", null ],
     [ "getTopFocusWindow", "interfacecom_1_1sun_1_1star_1_1ui_1_1test_1_1XUITest.html#a20f6be23487ddc362b888e4b803aadae", null ],
     [ "getWindow", "interfacecom_1_1sun_1_1star_1_1ui_1_1test_1_1XUITest.html#a7b1f22b11fe6eecb34d0400a4f2ecb8c", null ]
 ];
\ No newline at end of file
