@@ -325,16 +325,6 @@ var namespacecom_1_1sun_1_1star_1_1text =
       [ "TB_RL", "namespacecom_1_1sun_1_1star_1_1text_1_1WritingMode2.html#a9c68fece2094cf304a00f4d5010955af", null ],
       [ "TB_RL90", "namespacecom_1_1sun_1_1star_1_1text_1_1WritingMode2.html#a189c2e38deaf5a632ae65cf1455b5fe2", null ]
     ] ],
-    [ "AccessibleEndnoteView", "servicecom_1_1sun_1_1star_1_1text_1_1AccessibleEndnoteView.html", "servicecom_1_1sun_1_1star_1_1text_1_1AccessibleEndnoteView" ],
-    [ "AccessibleFootnoteView", "servicecom_1_1sun_1_1star_1_1text_1_1AccessibleFootnoteView.html", "servicecom_1_1sun_1_1star_1_1text_1_1AccessibleFootnoteView" ],
-    [ "AccessibleHeaderFooterView", "servicecom_1_1sun_1_1star_1_1text_1_1AccessibleHeaderFooterView.html", "servicecom_1_1sun_1_1star_1_1text_1_1AccessibleHeaderFooterView" ],
-    [ "AccessiblePageView", "servicecom_1_1sun_1_1star_1_1text_1_1AccessiblePageView.html", "servicecom_1_1sun_1_1star_1_1text_1_1AccessiblePageView" ],
-    [ "AccessibleParagraphView", "servicecom_1_1sun_1_1star_1_1text_1_1AccessibleParagraphView.html", "servicecom_1_1sun_1_1star_1_1text_1_1AccessibleParagraphView" ],
-    [ "AccessibleTextDocumentPageView", "servicecom_1_1sun_1_1star_1_1text_1_1AccessibleTextDocumentPageView.html", "servicecom_1_1sun_1_1star_1_1text_1_1AccessibleTextDocumentPageView" ],
-    [ "AccessibleTextDocumentView", "servicecom_1_1sun_1_1star_1_1text_1_1AccessibleTextDocumentView.html", "servicecom_1_1sun_1_1star_1_1text_1_1AccessibleTextDocumentView" ],
-    [ "AccessibleTextEmbeddedObject", "servicecom_1_1sun_1_1star_1_1text_1_1AccessibleTextEmbeddedObject.html", "servicecom_1_1sun_1_1star_1_1text_1_1AccessibleTextEmbeddedObject" ],
-    [ "AccessibleTextFrameView", "servicecom_1_1sun_1_1star_1_1text_1_1AccessibleTextFrameView.html", "servicecom_1_1sun_1_1star_1_1text_1_1AccessibleTextFrameView" ],
-    [ "AccessibleTextGraphicObject", "servicecom_1_1sun_1_1star_1_1text_1_1AccessibleTextGraphicObject.html", "servicecom_1_1sun_1_1star_1_1text_1_1AccessibleTextGraphicObject" ],
     [ "AutoTextContainer", "servicecom_1_1sun_1_1star_1_1text_1_1AutoTextContainer.html", null ],
     [ "AutoTextEntry", "servicecom_1_1sun_1_1star_1_1text_1_1AutoTextEntry.html", "servicecom_1_1sun_1_1star_1_1text_1_1AutoTextEntry" ],
     [ "AutoTextGroup", "servicecom_1_1sun_1_1star_1_1text_1_1AutoTextGroup.html", "servicecom_1_1sun_1_1star_1_1text_1_1AutoTextGroup" ],
